.. _hubugs-label:

.. module:: hubugs

:mod:`hubugs`
=============

:mod:`hubugs` is a very simple client for working with `GitHub's issue
tracker`_ from the command line.

It is written in Python_, and works with Python 2.6 and newer(including Python
3).  :mod:`hubugs` is released under the `GPL v3`_

.. important::

   This package is in a *rapid* state of flux right now, as support for version
   3 of the `GitHub API`_ is added.  Be aware there may be some significant
   changes to the user interface coming soon!

:Git repository:  https://github.com/JNRowe/hubugs/
:Issue tracker:  https://github.com/JNRowe/hubugs/issues/
:Contributors:  https://github.com/JNRowe/hubugs/contributors/

Contents
--------

.. toctree::
   :maxdepth: 2

   background
   install
   config
   usage
   templates
   hubugs manpage <hubugs.1>
   faq
   alternatives
   release
   appendix

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _Github's issue tracker: http://github.com/blog/411-github-issue-tracker
.. _Python: http://www.python.org/
.. _GPL v3: http://www.gnu.org/licenses/
.. _GitHub API: http://developer.github.com/v3/
